@@ -5,17 +5,13 @@ fi
 
 ( cd usr/lib ; rm -rf libkatepartinterfaces.so )
 ( cd usr/lib ; ln -sf libkatepartinterfaces.so.4 libkatepartinterfaces.so )
-( cd usr/lib ; rm -rf libktexteditor_codesnippets_core.so.0 )
-( cd usr/lib ; ln -sf libktexteditor_codesnippets_core.so.0.0.1 libktexteditor_codesnippets_core.so.0 )
-( cd usr/lib ; rm -rf libkatepartinterfaces.so.4 )
-( cd usr/lib ; ln -sf libkatepartinterfaces.so.4.8.0 libkatepartinterfaces.so.4 )
-( cd usr/lib ; rm -rf libktexteditor_codesnippets_core.so )
-( cd usr/lib ; ln -sf libktexteditor_codesnippets_core.so.0 libktexteditor_codesnippets_core.so )
-( cd usr/lib ; rm -rf libkateinterfaces.so.4 )
-( cd usr/lib ; ln -sf libkateinterfaces.so.4.8.0 libkateinterfaces.so.4 )
 ( cd usr/lib ; rm -rf libkateinterfaces.so )
 ( cd usr/lib ; ln -sf libkateinterfaces.so.4 libkateinterfaces.so )
-( cd usr/doc/HTML/en/kwrite ; rm -rf common )
-( cd usr/doc/HTML/en/kwrite ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/lib ; rm -rf libkateinterfaces.so.4 )
+( cd usr/lib ; ln -sf libkateinterfaces.so.4.10.5 libkateinterfaces.so.4 )
+( cd usr/lib ; rm -rf libkatepartinterfaces.so.4 )
+( cd usr/lib ; ln -sf libkatepartinterfaces.so.4.10.5 libkatepartinterfaces.so.4 )
 ( cd usr/doc/HTML/en/kate ; rm -rf common )
 ( cd usr/doc/HTML/en/kate ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/doc/HTML/en/kwrite ; rm -rf common )
+( cd usr/doc/HTML/en/kwrite ; ln -sf /usr/share/doc/HTML/en/common common )
